@@ -190,17 +190,12 @@ playlist::PlayPrevious(PlayerControl &pc)
 }
 
 PlaylistResult
-playlist::SeekSongPosition(PlayerControl &pc, unsigned song, float seek_time)
+playlist::SeekSongOrder(PlayerControl &pc, unsigned i, float seek_time)
 {
-	if (!queue.IsValidPosition(song))
-		return PlaylistResult::BAD_RANGE;
+	assert(queue.IsValidOrder(i));
 
 	const Song *queued_song = GetQueuedSong();
 
-	unsigned i = queue.random
-		? queue.PositionToOrder(song)
-		: song;
-
 	pc.ClearError();
 	stop_on_error = true;
 	error_count = 0;
@@ -228,6 +223,19 @@ playlist::SeekSongPosition(PlayerControl &pc, unsigned song, float seek_time)
 	return PlaylistResult::SUCCESS;
 }
 
+PlaylistResult
+playlist::SeekSongPosition(PlayerControl &pc, unsigned song, float seek_time)
+{
+	if (!queue.IsValidPosition(song))
+		return PlaylistResult::BAD_RANGE;
+
+	unsigned i = queue.random
+		? queue.PositionToOrder(song)
+		: song;
+
+	return SeekSongOrder(pc, i, seek_time);
+}
+
 PlaylistResult
 playlist::SeekSongId(PlayerControl &pc, unsigned id, float seek_time)
 {
@@ -257,5 +265,5 @@ playlist::SeekCurrent(PlayerControl &pc, float seek_time, bool relative)
 	if (seek_time < 0)
 		seek_time = 0;
 
-	return SeekSongPosition(pc, current, seek_time);
+	return SeekSongOrder(pc, current, seek_time);
 }
