@@ -983,10 +983,10 @@ input_curl_easy_init(struct input_curl *c, Error &error)
 			 input_curl_writefunction);
 	curl_easy_setopt(c->easy, CURLOPT_WRITEDATA, c);
 	curl_easy_setopt(c->easy, CURLOPT_HTTP200ALIASES, http_200_aliases);
-	curl_easy_setopt(c->easy, CURLOPT_FOLLOWLOCATION, 1);
-	curl_easy_setopt(c->easy, CURLOPT_NETRC, 1);
-	curl_easy_setopt(c->easy, CURLOPT_MAXREDIRS, 5);
-	curl_easy_setopt(c->easy, CURLOPT_FAILONERROR, true);
+	curl_easy_setopt(c->easy, CURLOPT_FOLLOWLOCATION, 1l);
+	curl_easy_setopt(c->easy, CURLOPT_NETRC, 1l);
+	curl_easy_setopt(c->easy, CURLOPT_MAXREDIRS, 5l);
+	curl_easy_setopt(c->easy, CURLOPT_FAILONERROR, 1l);
 	curl_easy_setopt(c->easy, CURLOPT_ERRORBUFFER, c->error);
 	curl_easy_setopt(c->easy, CURLOPT_NOPROGRESS, 1l);
 	curl_easy_setopt(c->easy, CURLOPT_NOSIGNAL, 1l);
